Utilities for making binary parsers
===================================

BinaryParser
~~~~~~~~~~~~

.. autoclass:: satella.parsing.BinaryParser
    :members:


NotEnoughBytes
~~~~~~~~~~~~~~

.. autoclass:: satella.exceptions.NotEnoughBytes
    :members:
